xbatcher: Batch Generation from Xarray Datasets
===============================================

|Build Status| |codecov| |docs| |license|


Xbatcher is a small library for iterating xarray DataArrays in batches. The
goal is to make it easy to feed xarray datasets to machine learning libraries
such as Keras_. View the |docs| for more info.

.. _Keras: https://keras.io/


.. |Build Status| image:: https://github.com/pangeo-data/xbatcher/workflows/CI/badge.svg
   :target: https://github.com/pangeo-data/xbatcher/actions
   :alt: github actions build status
.. |codecov| image:: https://codecov.io/gh/pangeo-data/xbatcher/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/pangeo-data/xbatcher
   :alt: code coverage
.. |docs| image:: http://readthedocs.org/projects/xbatcher/badge/?version=latest
   :target: http://xbatcher.readthedocs.org/en/latest/?badge=latest
.. |license| image:: https://img.shields.io/github/license/mashape/apistatus.svg
   :target: https://github.com/pangeo-data/xbatcher
   :alt: license
